Reconstruct fitted or subsetted outputs for a regress object
reconstruct.regress.RdFor regression-based bi_projectors, reconstruction should map from the design matrix side (scores) to the output space using the regression coefficients, without applying any reverse preprocessing (which belongs to the input/basis side).
Arguments
- x
A
regressobject produced byregress().- comp
Integer vector of component indices (columns of the design matrix / predictors) to use.
- rowind
Integer vector of row indices in the design matrix (observations) to reconstruct.
- colind
Integer vector of output indices (columns of Y) to reconstruct.
- ...
Ignored.