Compose Multiple Partial Projectors
compose_partial_projector.RdCreates a composed_partial_projector object that applies projectors sequentially.
For partial projection, colind is applied to the first stage only; later
stages receive the full output from the preceding stage.
This infix operator provides syntactic sugar for composing projectors sequentially.
It is an alias for compose_partial_projector.
Arguments
- ...
A sequence of projectors that implement
partial_project(), optionally named.- lhs
The left-hand side projector (or a composed projector).
- rhs
The right-hand side projector to add to the sequence.